@@ -1,6 +1,6 @@
 {
     'name': "Odoo customizations for Onaro",
-    'version': '12.0.0.1.0',
+    'version': '12.0.0.1.1',
     'author': "Coopdevs Treball SCCL",
     'depends': [
         'auth_api_key',
@@ -9,6 +9,7 @@
         'base_rest',
         'crm_lead_product',
         'helpdesk_mgmt',
+        'partner_firstname',
         'remove_dup_acc_num_constraint',
         'telecom',
     ],
@@ -27,10 +28,6 @@
     'data': [
         'data/base_automation.xml',
         'data/ir_default.xml',
-        'data/product_attribute_value.xml',
-        'data/product_product.xml',
-        'data/product_template_attribute_line.xml',
-        'data/product_template.xml',
         'views/crm_lead.xml',
         'security/res_users.xml',
     ],
