@@ -9,13 +9,12 @@ class CrmLead(models.Model):
             ('login', '=', "bulegoa@onaro.eus")
         ])
 
-    birth_date = fields.Char(string="Birth Date")
-    dni = fields.Char(string="DNI")
-    iban = fields.Char(string="IBAN")
+    def _language_selection(self):
+        return [
+            ('eu_ES', 'EU'), ('es_ES', 'ES')
+        ]
+
+    # TODO: Move to module telecom invoice address??
     invoice_address = fields.Char(string="Invoice Address")
-    language = fields.Selection(
-        [('eu_ES', 'EU'), ('es', 'ES')],
-        string="Language")
-    policy_accepted = fields.Boolean(string="Policy accepted")
     portability_number = fields.Char(string="Portability Number")
     user_id = fields.Many2one(default=_get_default_user_id)
