@@ -8,12 +8,12 @@ HOST = "127.0.0.1"
 PORT = odoo.tools.config["http_port"]
 
 
-class BaseEMCRestCase(BaseRestCase):
+class BaseOnaroRestCase(BaseRestCase):
     @classmethod
     def setUpClass(cls, *args, **kwargs):
         super().setUpClass(*args, **kwargs)
         cls.AuthApiKey = cls.env["auth.api.key"]
-        cls.api_key_test = cls.env.ref("onaro.auth_api_key_manager_emc_demo")
+        cls.api_key_test = cls.env.ref("onaro.auth_api_key_manager_demo")
 
     def setUp(self):
         super().setUp()
@@ -26,3 +26,10 @@ class BaseEMCRestCase(BaseRestCase):
         else:
             headers = key_dict
         return headers
+
+    def http_post(self, url, data, headers=None):
+        headers = self._add_api_key(headers)
+        if url.startswith("/"):
+            url = "http://{}:{}{}".format(HOST, PORT, url)
+
+        return self.session.post(url, json=data, headers=headers)
